==> 8.2.zip: 8.2/get_inventory_stock_receive_po_list.php <==
<?php
require_once('config.php');

$error_message;
$valid = true;


// SELECT
  // CASE
    // WHEN puo_ls1.puo_ls1_rcv_qty = '.0000' THEN '0'
    // ELSE puo_ls1.puo_ls1_rcv_qty
  // END AS adjusted_value
// FROM your_table;



$sql = "SELECT 	puo_ls1.puo_ls1_po_lineno,   
			puo_ls1.puo_ls1_stk_locn, 
			puo_ls1.puo_ls1_description,   
			puo_ls1.puo_ls1_ord_uom,   
			puo_ls1_item_cost = CAST(CAST(puo_ls1.puo_ls1_item_cost AS DECIMAL(10,2)) AS VARCHAR),  
			puo_ls1_retail_price = CAST(CAST(puo_ls1.puo_ls1_retail_price AS DECIMAL(10,2)) AS VARCHAR),    
			puo_ls1_ord_qty = CAST(CAST(puo_ls1.puo_ls1_ord_qty AS DECIMAL(10,2)) AS VARCHAR),   
			puo_ls1_rcv_qty = CAST(CAST(puo_ls1.puo_ls1_rcv_qty AS DECIMAL(10,2)) AS VARCHAR),
			puo_ls1_bo_qty = CAST(CAST(puo_ls1.puo_ls1_bo_qty AS DECIMAL(10,2)) AS VARCHAR),   
			puo_ls1_invoice_qty = CAST(CAST(puo_ls1.puo_ls1_invoice_qty AS DECIMAL(10,2)) AS VARCHAR),
			puo_ls1.puo_ls1_tax_code,              
			puo_ls1_tax_rate = CAST(CAST(puo_ls1.puo_ls1_tax_rate AS DECIMAL(10,2)) AS VARCHAR),            
			puo_ls1.puo_ls1_projectid,   
			puo_ls1.puo_ls1_wo_no,   
			puo_ls1.puo_ls1_markfor,
			puo_ls1.puo_ls1_stockno,   
			puo_ls1_chg_costcenter,
			puo_ls1_chg_account,
			puo_ls1_pr_no,
			puo_ls1_pr_lineno, 
			puo_ls1_contract_id,
			puo_ls1_contract_lineno,
			puo_ls1_item_category,
			puo_ls1_clo_date,
			receive_qty = CAST(CAST(COALESCE(puo_ls1.puo_ls1_ord_qty, 0)  - COALESCE(puo_ls1.puo_ls1_rcv_qty, 0) + COALESCE(puo_ls1.puo_ls1_invoice_qty, 0)  AS DECIMAL(10,2)) AS VARCHAR),
			rowid
	FROM 	puo_ls1   (NOLOCK)
	WHERE 	COALESCE(puo_ls1.puo_ls1_ord_qty, 0)  - COALESCE(puo_ls1.puo_ls1_rcv_qty, 0) + COALESCE(puo_ls1.puo_ls1_invoice_qty, 0) > 0  
	AND 	puo_ls1.mst_RowID = '".$_REQUEST['mst_RowID']."'";
						
$stmt = sqlsrv_query( $conn, $sql);

if( !$stmt ) {
     $error_message = "Error selecting table (puo_ls1)";
	 returnError($error_message);
     die( print_r( sqlsrv_errors(), true));
}

$json = array();

do {
     while ($row = sqlsrv_fetch_array($stmt, SQLSRV_FETCH_ASSOC)) {
		 
		$json[] = $row;
		
						
     }
} while ( sqlsrv_next_result($stmt) );

if ($valid) {
	sqlsrv_free_stmt( $stmt);
	sqlsrv_close( $conn);	
	
	returnData($json);	
}

function returnData($json){
	$returnData = array(
	'status' => 'SUCCESS',	
	'data' => $json);
	
	echo json_encode($returnData);
}

function returnError($error_message){
	$json = array();
	
	$returnData = array(
	'status' => 'ERROR',	
	'data' => $json);
	
	echo json_encode($returnData);
	
	
		
	exit();
}
	


?>

==> 9.2.zip: 9.2/get_inventory_stock_receive_po_list.php <==
<?php
require_once('config.php');

$error_message;
$valid = true;


// SELECT
  // CASE
    // WHEN puo_ls1.puo_ls1_rcv_qty = '.0000' THEN '0'
    // ELSE puo_ls1.puo_ls1_rcv_qty
  // END AS adjusted_value
// FROM your_table;



$sql = "SELECT 	puo_ls1.puo_ls1_po_lineno,   
			puo_ls1.puo_ls1_stk_locn, 
			puo_ls1.puo_ls1_description,   
			puo_ls1.puo_ls1_ord_uom,   
			puo_ls1_item_cost = CAST(CAST(puo_ls1.puo_ls1_item_cost AS DECIMAL(10,2)) AS VARCHAR),  
			puo_ls1_retail_price = CAST(CAST(puo_ls1.puo_ls1_retail_price AS DECIMAL(10,2)) AS VARCHAR),    
			puo_ls1_ord_qty = CAST(CAST(puo_ls1.puo_ls1_ord_qty AS DECIMAL(10,2)) AS VARCHAR),   
			puo_ls1_rcv_qty = CAST(CAST(puo_ls1.puo_ls1_rcv_qty AS DECIMAL(10,2)) AS VARCHAR),
			puo_ls1_bo_qty = CAST(CAST(puo_ls1.puo_ls1_bo_qty AS DECIMAL(10,2)) AS VARCHAR),   
			puo_ls1_invoice_qty = CAST(CAST(puo_ls1.puo_ls1_invoice_qty AS DECIMAL(10,2)) AS VARCHAR),
			puo_ls1.puo_ls1_tax_code,              
			puo_ls1_tax_rate = CAST(CAST(puo_ls1.puo_ls1_tax_rate AS DECIMAL(10,2)) AS VARCHAR),            
			puo_ls1.puo_ls1_projectid,   
			puo_ls1.puo_ls1_wo_no,   
			puo_ls1.puo_ls1_markfor,
			puo_ls1.puo_ls1_stockno,   
			puo_ls1_chg_costcenter,
			puo_ls1_chg_account,
			puo_ls1_pr_no,
			puo_ls1_pr_lineno, 
			puo_ls1_contract_id,
			puo_ls1_contract_lineno,
			puo_ls1_item_category,
			puo_ls1_clo_date,
			receive_qty = CAST(CAST(COALESCE(puo_ls1.puo_ls1_ord_qty, 0)  - COALESCE(puo_ls1.puo_ls1_rcv_qty, 0) + COALESCE(puo_ls1.puo_ls1_invoice_qty, 0)  AS DECIMAL(10,2)) AS VARCHAR),
			remain_qty  = CAST(CAST(COALESCE(puo_ls1.puo_ls1_ord_qty, 0)  - COALESCE(puo_ls1.puo_ls1_rcv_qty, 0) + COALESCE(puo_ls1.puo_ls1_invoice_qty, 0)  AS DECIMAL(10,2)) AS VARCHAR),
			
			rowid
	FROM 	puo_ls1   (NOLOCK)
	WHERE 	COALESCE(puo_ls1.puo_ls1_ord_qty, 0)  - COALESCE(puo_ls1.puo_ls1_rcv_qty, 0) + COALESCE(puo_ls1.puo_ls1_invoice_qty, 0) > 0  
	AND 	puo_ls1.mst_RowID = '".$_REQUEST['mst_RowID']."'";
						
$stmt = sqlsrv_query( $conn, $sql);

if( !$stmt ) {
     $error_message = "Error selecting table (puo_ls1)";
	 returnError($error_message);
     die( print_r( sqlsrv_errors(), true));
}

$json = array();

do {
     while ($row = sqlsrv_fetch_array($stmt, SQLSRV_FETCH_ASSOC)) {
		 
		$json[] = $row;
		
						
     }
} while ( sqlsrv_next_result($stmt) );

if ($valid) {
	sqlsrv_free_stmt( $stmt);
	sqlsrv_close( $conn);	
	
	returnData($json);	
}

function returnData($json){
	$returnData = array(
	'status' => 'SUCCESS',	
	'data' => $json);
	
	echo json_encode($returnData);
}

function returnError($error_message){
	$json = array();
	
	$returnData = array(
	'status' => 'ERROR',	
	'data' => $json);
	
	echo json_encode($returnData);
	
	
		
	exit();
}
	


?>
